@@ -1,6 +1,6 @@
 
-def encline(x1,y1,x2,y2):   #encode line.
-    return [['%s %s %s %s,' % (b32e(x1),b32e(y1),b32e(x2),b32e(y2))]]
+def encline(points):   #encode line.
+	return [[' '.join([b32e(point) for point in points]) + ',']]
 
 def encpup(x,y,pupcode):
     #encode powerup without rotation
